<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ArmyWidget</name>
    <message>
        <location filename="../inspector/armywidget.ui" line="23"/>
        <source>Army settings</source>
        <translation>Einstellungen der Armee</translation>
    </message>
    <message>
        <location filename="../inspector/armywidget.ui" line="121"/>
        <source>Wide formation</source>
        <translation>Breite Formation</translation>
    </message>
    <message>
        <location filename="../inspector/armywidget.ui" line="108"/>
        <source>Tight formation</source>
        <translation>Enge Formation</translation>
    </message>
</context>
<context>
    <name>EventSettings</name>
    <message>
        <location filename="../mapsettings/eventsettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/eventsettings.ui" line="34"/>
        <source>Timed events</source>
        <translation>Zeitlich begrenzte Ereignisse</translation>
    </message>
    <message>
        <location filename="../mapsettings/eventsettings.ui" line="60"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../mapsettings/eventsettings.ui" line="73"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../mapsettings/eventsettings.cpp" line="101"/>
        <source>New event</source>
        <translation>Neues Ereignis</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../mapsettings/generalsettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/generalsettings.ui" line="32"/>
        <source>Map name</source>
        <translation>Kartenname</translation>
    </message>
    <message>
        <location filename="../mapsettings/generalsettings.ui" line="42"/>
        <source>Map description</source>
        <translation>Kartenbeschreibung</translation>
    </message>
    <message>
        <location filename="../mapsettings/generalsettings.ui" line="76"/>
        <source>Limit maximum heroes level</source>
        <translation>Maximales Level des Helden begrenzen</translation>
    </message>
    <message>
        <location filename="../mapsettings/generalsettings.ui" line="85"/>
        <source>Difficulty</source>
        <translation>Schwierigkeit</translation>
    </message>
</context>
<context>
    <name>GeneratorProgress</name>
    <message>
        <location filename="../generatorprogress.ui" line="29"/>
        <source>Generating map</source>
        <translation>Karte generieren</translation>
    </message>
</context>
<context>
    <name>HeroSkillsWidget</name>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="14"/>
        <source>Hero skills</source>
        <translation>Helden-Fertigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="28"/>
        <location filename="../inspector/heroskillswidget.ui" line="38"/>
        <location filename="../inspector/heroskillswidget.ui" line="48"/>
        <location filename="../inspector/heroskillswidget.ui" line="58"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="97"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="113"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="153"/>
        <source>Skill</source>
        <translation>Fertigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="158"/>
        <source>Level</source>
        <translation>Level</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.ui" line="166"/>
        <source>Customize skills</source>
        <translation>Fertigkeiten anpassen</translation>
    </message>
</context>
<context>
    <name>LoseConditions</name>
    <message>
        <location filename="../mapsettings/loseconditions.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.ui" line="40"/>
        <source>Defeat message</source>
        <translation>Niederlage-Nachricht</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.ui" line="59"/>
        <source>7 days without town</source>
        <translation>7 Tage ohne Stadt</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.ui" line="72"/>
        <source>Parameters</source>
        <translation>Parameter</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.cpp" line="37"/>
        <source>No special loss</source>
        <translation>Keine besondere Niederlage</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.cpp" line="38"/>
        <source>Lose castle</source>
        <translation>Schloss verlieren</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.cpp" line="39"/>
        <source>Lose hero</source>
        <translation>Held verlieren</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.cpp" line="40"/>
        <source>Time expired</source>
        <translation>Zeit abgelaufen</translation>
    </message>
    <message>
        <location filename="../mapsettings/loseconditions.cpp" line="41"/>
        <source>Days without town</source>
        <translation>Tage ohne Stadt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>VCMI Map Editor</source>
        <translation>VCMI-Karteneditor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Player</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Toolbar</source>
        <translation>Werkzeugleiste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="183"/>
        <source>Minimap</source>
        <translation>Minikarte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Map Objects View</source>
        <translation>Kartenobjekte-Ansicht</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <source>Browser</source>
        <translation>Browser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Inspector</source>
        <translation>Inspektor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Property</source>
        <translation>Eigenschaft</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <source>Painting</source>
        <translation>Malen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="897"/>
        <source>Terrains</source>
        <translation>Terrains</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="940"/>
        <source>Roads</source>
        <translation>Straßen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="980"/>
        <source>Rivers</source>
        <translation>Flüsse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1014"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1052"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1076"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1084"/>
        <source>Save as...</source>
        <translation>Speichern unter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1087"/>
        <source>Ctrl+Shift+S</source>
        <translation>Strg+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1096"/>
        <source>U/G</source>
        <translation>U/G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>View underground</source>
        <translation>Ansicht Untergrund</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1114"/>
        <source>Pass</source>
        <translation>Passierbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1138"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1150"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1162"/>
        <source>Fill</source>
        <translation>Füllen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Fills the selection with obstacles</source>
        <translation>Füllt die Auswahl mit Hindernissen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1180"/>
        <source>Grid</source>
        <translation>Raster</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1191"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1194"/>
        <source>Map title and description</source>
        <translation>Titel und Beschreibung der Karte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <source>Players settings</source>
        <translation>Spieler-Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1220"/>
        <location filename="../mainwindow.ui" line="1223"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1241"/>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Erase</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1270"/>
        <source>Neutral</source>
        <translation>Neutral</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1278"/>
        <source>Validate</source>
        <translation>Validieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1289"/>
        <location filename="../mainwindow.cpp" line="1053"/>
        <location filename="../mainwindow.cpp" line="1057"/>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>Update appearance</source>
        <translation>Aussehen aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1300"/>
        <source>Recreate obstacles</source>
        <translation>Hindernisse neu erschaffen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1311"/>
        <source>Player 1</source>
        <translation>Spieler 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1322"/>
        <source>Player 2</source>
        <translation>Spieler 2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1333"/>
        <source>Player 3</source>
        <translation>Spieler 3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1344"/>
        <source>Player 4</source>
        <translation>Spieler 4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>Player 5</source>
        <translation>Spieler 5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>Player 6</source>
        <translation>Spieler 6</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1377"/>
        <source>Player 7</source>
        <translation>Spieler 7</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1388"/>
        <source>Player 8</source>
        <translation>Spieler 8</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1396"/>
        <source>Export as...</source>
        <translation>Exportieren als...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1408"/>
        <source>Translations</source>
        <translation>Übersetzungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1411"/>
        <source>Ctrl+T</source>
        <translation>Strg+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1416"/>
        <location filename="../mainwindow.ui" line="1419"/>
        <source>h3m converter</source>
        <translation>h3m-Konverter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1428"/>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>Lock objects on map to avoid unnecessary changes</source>
        <translation>Objekte auf der Karte sperren, um unnötige Änderungen zu vermeiden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1434"/>
        <source>Ctrl+L</source>
        <translation>Strg+L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1443"/>
        <source>Unlock</source>
        <translation>Entsperren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1446"/>
        <source>Unlock all objects on the map</source>
        <translation>Entsperre alle Objekte auf der Karte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1449"/>
        <source>Ctrl+Shift+L</source>
        <translation>Strg+Umschalt+L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Zoom in</source>
        <translation>Heranzoomen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1461"/>
        <source>Ctrl+=</source>
        <translation>Strg+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1470"/>
        <source>Zoom out</source>
        <translation>Herauszoomen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1473"/>
        <source>Ctrl+-</source>
        <translation>Strg+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Zoom reset</source>
        <translation>Zoom zurücksetzen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1485"/>
        <source>Ctrl+Shift+=</source>
        <translation>Strg+Umschalt+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Unsaved changes will be lost, are you sure?</source>
        <translation>Ungespeicherte Änderungen gehen verloren, sind sie sicher?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="384"/>
        <source>Open map</source>
        <translation>Karte öffnen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>All supported maps (*.vmap *.h3m);;VCMI maps(*.vmap);;HoMM3 maps(*.h3m)</source>
        <translation>Alle unterstützten Karten (*.vmap *.h3m);;VCMI-Karten (*.vmap);;HoMM3-Karten (*.h3m)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Save map</source>
        <translation>Karte speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>VCMI maps (*.vmap)</source>
        <translation>VCMI-Karten (*.vmap)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="786"/>
        <source>View surface</source>
        <translation>Oberfläche anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1053"/>
        <source>No objects selected</source>
        <translation>Keine Objekte selektiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>This operation is irreversible. Do you want to continue?</source>
        <translation>Diese Operation ist unumkehrbar. Möchten sie fortsetzen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>Errors occurred. %1 objects were not updated</source>
        <translation>Fehler sind aufgetreten. %1 Objekte konnten nicht aktualisiert werden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1154"/>
        <source>Save to image</source>
        <translation>Als Bild speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1173"/>
        <source>Select maps to convert</source>
        <translation>Zu konvertierende Karten auswählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>HoMM3 maps(*.h3m)</source>
        <translation>HoMM3-Karten (*.h3m)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Choose directory to save converted maps</source>
        <translation>Verzeichnis zum Speichern der konvertierten Karten wählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1192"/>
        <source>Operation completed</source>
        <translation>Vorgang abgeschlossen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1192"/>
        <source>Successfully converted %1 maps</source>
        <translation>Erfolgreiche Konvertierung von %1 Karten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1196"/>
        <source>Failed to convert the map. Abort operation</source>
        <translation>Die Karte konnte nicht konvertiert werden. Vorgang abgebrochen</translation>
    </message>
</context>
<context>
    <name>MapSettings</name>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="23"/>
        <source>Map settings</source>
        <translation>Karteneinstellungen</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="42"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="61"/>
        <source>Mods</source>
        <translation>Mods</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="80"/>
        <source>Events</source>
        <translation>Ereignisse</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="99"/>
        <source>Victory</source>
        <translation>Sieg</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="118"/>
        <source>Loss</source>
        <translation>Niederlage</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="137"/>
        <source>Timed</source>
        <translation>Zeitgesteuert</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="156"/>
        <source>Rumors</source>
        <translation>Gerüchte</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="179"/>
        <source>Abilities</source>
        <translation>Fähigkeiten</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="214"/>
        <source>Spells</source>
        <translation>Zaubersprüche</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="249"/>
        <source>Artifacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="284"/>
        <source>Heroes</source>
        <translation>Helden</translation>
    </message>
    <message>
        <location filename="../mapsettings/mapsettings.ui" line="322"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>MapView</name>
    <message>
        <location filename="../mapview.cpp" line="625"/>
        <source>Can&apos;t place object</source>
        <translation>Objekt kann nicht platziert werden</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="../inspector/messagewidget.ui" line="23"/>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
</context>
<context>
    <name>ModSettings</name>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="32"/>
        <source>Mandatory mods to play this map</source>
        <translation>Benötigte Mods zum Spielen dieser Karte</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="46"/>
        <source>Mod name</source>
        <translation>Mod Name</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="51"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="61"/>
        <source>Automatic assignment</source>
        <translation>Automatische Zuweisung</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="68"/>
        <source>Set required mods based on objects placed on the map. This method may cause problems if you have customized rewards, garrisons, etc from mods</source>
        <translation>Erforderliche Mods anhand der auf der Karte platzierten Objekte festlegen. Diese Methode kann Probleme verursachen, wenn Belohnungen, Garnisonen usw. von Mods angepasst wurden</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="71"/>
        <source>Map objects mods</source>
        <translation>Mods für Kartenobjekte</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="81"/>
        <source>Set all mods having a game content as mandatory</source>
        <translation>Alle Mods, die einen Spielinhalt haben, als notwendig festlegen</translation>
    </message>
    <message>
        <location filename="../mapsettings/modsettings.ui" line="84"/>
        <source>Full content mods</source>
        <translation>Vollwertige Mods</translation>
    </message>
</context>
<context>
    <name>PlayerParams</name>
    <message>
        <location filename="../playerparams.ui" line="89"/>
        <source>Human/CPU</source>
        <translation>Mensch/CPU</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="76"/>
        <source>CPU only</source>
        <translation>Nur CPU</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="96"/>
        <source>Team</source>
        <translation>Team</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="134"/>
        <source>Main town</source>
        <translation>Hauptstadt</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="117"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="164"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="221"/>
        <source>Random faction</source>
        <translation>Zufällige Fraktion</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="179"/>
        <source>Generate hero at main</source>
        <translation>Held am Hauptplatz generieren</translation>
    </message>
    <message>
        <location filename="../playerparams.ui" line="156"/>
        <source>(default)</source>
        <translation>(Standard)</translation>
    </message>
    <message>
        <location filename="../playerparams.cpp" line="111"/>
        <source>Player ID: %1</source>
        <translation>Spieler-ID: %1</translation>
    </message>
</context>
<context>
    <name>PlayerSettings</name>
    <message>
        <location filename="../playersettings.ui" line="20"/>
        <source>Player settings</source>
        <translation>Spieler-Einstellungen</translation>
    </message>
    <message>
        <location filename="../playersettings.ui" line="63"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../playersettings.ui" line="74"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../playersettings.ui" line="117"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>PortraitWidget</name>
    <message>
        <location filename="../inspector/portraitwidget.ui" line="14"/>
        <source>Portrait</source>
        <translation>Porträt</translation>
    </message>
    <message>
        <location filename="../inspector/portraitwidget.ui" line="52"/>
        <location filename="../inspector/portraitwidget.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../inspector/portraitwidget.ui" line="85"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../inspector/heroskillswidget.cpp" line="19"/>
        <source>Beginner</source>
        <translation>Anfänger</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.cpp" line="20"/>
        <source>Advanced</source>
        <translation>Fortgeschrittene</translation>
    </message>
    <message>
        <location filename="../inspector/heroskillswidget.cpp" line="21"/>
        <source>Expert</source>
        <translation>Experte</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="35"/>
        <source>Compliant</source>
        <translation>Konform</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="36"/>
        <source>Friendly</source>
        <translation>Freundlich</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="37"/>
        <source>Aggressive</source>
        <translation>Aggressiv</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="38"/>
        <source>Hostile</source>
        <translation>Feindlich</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="39"/>
        <source>Savage</source>
        <translation>Wild</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="478"/>
        <location filename="../inspector/inspector.cpp" line="845"/>
        <source>neutral</source>
        <translation>neutral</translation>
    </message>
    <message>
        <location filename="../inspector/inspector.cpp" line="843"/>
        <source>UNFLAGGABLE</source>
        <translation>UNFLAGGBAR</translation>
    </message>
</context>
<context>
    <name>QuestWidget</name>
    <message>
        <location filename="../inspector/questwidget.ui" line="17"/>
        <source>Mission goal</source>
        <translation>Missionsziel</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="28"/>
        <source>Day of week</source>
        <translation>Tag der Woche</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="45"/>
        <source>Days passed</source>
        <translation>Verstrichene Tage</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="79"/>
        <source>Hero level</source>
        <translation>Heldenstufe</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="96"/>
        <source>Hero experience</source>
        <translation>Heldenerfahrung</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="136"/>
        <source>Spell points</source>
        <translation>Zauberpunkte</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="156"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="183"/>
        <source>Kill hero/monster</source>
        <translation>Held/Monster töten</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="197"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="206"/>
        <source>Primary skills</source>
        <translation>Primäre Fähigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="221"/>
        <source>Attack</source>
        <translation>Angriff</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="231"/>
        <source>Defence</source>
        <translation>Verteidigung</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="241"/>
        <source>Spell power</source>
        <translation>Zauberkraft</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="251"/>
        <source>Knowledge</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="289"/>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="338"/>
        <source>Artifacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="370"/>
        <source>Spells</source>
        <translation>Zaubersprüche</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="402"/>
        <source>Skills</source>
        <translation>Fertigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="442"/>
        <source>Creatures</source>
        <translation>Kreaturen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="491"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="498"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="538"/>
        <source>Heroes</source>
        <translation>Helden</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="570"/>
        <source>Hero classes</source>
        <translation>Heldenklassen</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.ui" line="602"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.cpp" line="34"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../inspector/questwidget.cpp" line="36"/>
        <source>Day %1</source>
        <translation>Tag %1</translation>
    </message>
</context>
<context>
    <name>RewardsWidget</name>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="17"/>
        <source>Rewards</source>
        <translation>Belohnungen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="33"/>
        <location filename="../inspector/rewardswidget.ui" line="703"/>
        <location filename="../inspector/rewardswidget.ui" line="818"/>
        <location filename="../inspector/rewardswidget.ui" line="1407"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="40"/>
        <location filename="../inspector/rewardswidget.ui" line="710"/>
        <location filename="../inspector/rewardswidget.ui" line="825"/>
        <location filename="../inspector/rewardswidget.ui" line="1414"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="61"/>
        <source>Visit mode</source>
        <translation>Besuchsmodus</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="82"/>
        <source>Select mode</source>
        <translation>Modus auswählen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="104"/>
        <source>On select text</source>
        <translation>Bei markiertem Text</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="111"/>
        <source>Can refuse</source>
        <translation>Kann ablehnen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="118"/>
        <source>Reset parameters</source>
        <translation>Parameter zurücksetzen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="138"/>
        <source>Period</source>
        <translation>Zeitraum</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="145"/>
        <source> days</source>
        <translation> Tage</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="157"/>
        <source>Reset visitors</source>
        <translation>Besucher zurücksetzen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="164"/>
        <source>Reset rewards</source>
        <translation>Belohnungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="176"/>
        <source>Window type</source>
        <translation>Fenstertyp</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="196"/>
        <source>Event info</source>
        <translation>Ereignis-Infos</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="214"/>
        <source>Message to be displayed on granting of this reward</source>
        <translation>Nachricht, die bei der Gewährung dieser Belohnung angezeigt wird</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="225"/>
        <source>Reward</source>
        <translation>Belohnung</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="245"/>
        <location filename="../inspector/rewardswidget.ui" line="1032"/>
        <source>Hero level</source>
        <translation>Heldenstufe</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="262"/>
        <location filename="../inspector/rewardswidget.ui" line="1049"/>
        <source>Hero experience</source>
        <translation>Heldenerfahrung</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="302"/>
        <location filename="../inspector/rewardswidget.ui" line="1089"/>
        <source>Spell points</source>
        <translation>Zauberpunkte</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="325"/>
        <location filename="../inspector/rewardswidget.ui" line="345"/>
        <location filename="../inspector/rewardswidget.ui" line="379"/>
        <location filename="../inspector/rewardswidget.ui" line="1109"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="338"/>
        <source>Overflow</source>
        <translation>Überlauf</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="362"/>
        <source>Movement</source>
        <translation>Bewegung</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="405"/>
        <source>Remove object</source>
        <translation>Objekt entfernen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="414"/>
        <location filename="../inspector/rewardswidget.ui" line="1134"/>
        <source>Primary skills</source>
        <translation>Primäre Fähigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="429"/>
        <location filename="../inspector/rewardswidget.ui" line="1149"/>
        <source>Attack</source>
        <translation>Angriff</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="443"/>
        <location filename="../inspector/rewardswidget.ui" line="1159"/>
        <source>Defence</source>
        <translation>Verteidigung</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="457"/>
        <location filename="../inspector/rewardswidget.ui" line="1169"/>
        <source>Spell power</source>
        <translation>Zauberkraft</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="471"/>
        <location filename="../inspector/rewardswidget.ui" line="1179"/>
        <source>Knowledge</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="501"/>
        <location filename="../inspector/rewardswidget.ui" line="1205"/>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="550"/>
        <location filename="../inspector/rewardswidget.ui" line="1254"/>
        <source>Artifacts</source>
        <translation>Artefakte</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="582"/>
        <location filename="../inspector/rewardswidget.ui" line="1286"/>
        <source>Spells</source>
        <translation>Zaubersprüche</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="614"/>
        <location filename="../inspector/rewardswidget.ui" line="1318"/>
        <source>Skills</source>
        <translation>Fertigkeiten</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="654"/>
        <location filename="../inspector/rewardswidget.ui" line="1358"/>
        <source>Creatures</source>
        <translation>Kreaturen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="747"/>
        <source>Bonuses</source>
        <translation>Boni</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="764"/>
        <location filename="../inspector/rewardswidget.ui" line="856"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="774"/>
        <location filename="../inspector/rewardswidget.ui" line="861"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="784"/>
        <location filename="../inspector/rewardswidget.ui" line="866"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="875"/>
        <source>Cast</source>
        <translation>Wirken</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="881"/>
        <source>Cast an adventure map spell</source>
        <translation>Einen Abenteuerkarten-Zauber wirken</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="890"/>
        <source>Spell</source>
        <translation>Zauberspruch</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="911"/>
        <source>Magic school level</source>
        <translation>Stufe der Zauberschule</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="961"/>
        <source>Limiter</source>
        <translation>Begrenzer</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="981"/>
        <source>Day of week</source>
        <translation>Tag der Woche</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="998"/>
        <source>Days passed</source>
        <translation>Verstrichene Tage</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="1454"/>
        <source>Heroes</source>
        <translation>Helden</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="1486"/>
        <source>Hero classes</source>
        <translation>Heldenklassen</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.ui" line="1518"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.cpp" line="45"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.cpp" line="47"/>
        <source>Day %1</source>
        <translation>Tag %1</translation>
    </message>
    <message>
        <location filename="../inspector/rewardswidget.cpp" line="234"/>
        <location filename="../inspector/rewardswidget.cpp" line="605"/>
        <source>Reward %1</source>
        <translation>Belohnung %1</translation>
    </message>
</context>
<context>
    <name>RumorSettings</name>
    <message>
        <location filename="../mapsettings/rumorsettings.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/rumorsettings.ui" line="37"/>
        <source>Tavern rumors</source>
        <translation>Tavernen-Gerüchte</translation>
    </message>
    <message>
        <location filename="../mapsettings/rumorsettings.ui" line="63"/>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <location filename="../mapsettings/rumorsettings.ui" line="82"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../mapsettings/rumorsettings.cpp" line="59"/>
        <source>New rumor</source>
        <translation>Neues Gerücht</translation>
    </message>
</context>
<context>
    <name>TimedEvent</name>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="17"/>
        <source>Timed event</source>
        <translation>Zeitgesteuertes Ereignis</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="28"/>
        <source>Event name</source>
        <translation>Name des Ereignisses</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="35"/>
        <source>Type event message text</source>
        <translation>Ereignistext eingeben</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="47"/>
        <source>affects human</source>
        <translation>beeinflusst Menschen</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="54"/>
        <source>affects AI</source>
        <translation>beeinflusst KI</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="70"/>
        <source>Day of first occurance</source>
        <translation>Tag des ersten Auftretens</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="87"/>
        <source>Repeat after (0 = no repeat)</source>
        <translation>Wiederholung nach (0 = keine Wiederholung)</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="108"/>
        <source>Affected players</source>
        <translation>Betroffene Spieler</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="131"/>
        <source>Resources</source>
        <translation>Ressourcen</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="190"/>
        <source>type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="195"/>
        <source>qty</source>
        <translation>anz.</translation>
    </message>
    <message>
        <location filename="../mapsettings/timedevent.ui" line="203"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>TownBulidingsWidget</name>
    <message>
        <location filename="../inspector/townbulidingswidget.ui" line="29"/>
        <source>Buildings</source>
        <translation>Gebäude</translation>
    </message>
</context>
<context>
    <name>Translations</name>
    <message>
        <location filename="../mapsettings/translations.ui" line="14"/>
        <source>Map translations</source>
        <translation>Übersetzungen der Karte</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.ui" line="31"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.ui" line="48"/>
        <source>Suppported</source>
        <translation>Unterstützt</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.ui" line="70"/>
        <source>String ID</source>
        <translation>String-ID</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.ui" line="75"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.cpp" line="156"/>
        <location filename="../mapsettings/translations.cpp" line="160"/>
        <source>Remove translation</source>
        <translation>Übersetzung entfernen</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.cpp" line="156"/>
        <source>Default language cannot be removed</source>
        <translation>Standardsprache kann nicht entfernt werden</translation>
    </message>
    <message>
        <location filename="../mapsettings/translations.cpp" line="160"/>
        <source>All existing text records for this language will be removed. Continue?</source>
        <translation>Alle vorhandenen Textsätze für diese Sprache werden entfernt. Weiter?</translation>
    </message>
</context>
<context>
    <name>Validator</name>
    <message>
        <location filename="../validator.ui" line="17"/>
        <source>Map validation results</source>
        <translation>Ergebnisse der Kartenvalidierung</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="52"/>
        <source>Map is not loaded</source>
        <translation>Karte ist nicht geladen</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="72"/>
        <source>No factions allowed for player %1</source>
        <translation>Keine Fraktionen für Spieler %1 erlaubt</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="75"/>
        <source>No players allowed to play this map</source>
        <translation>Keine Spieler dürfen diese Karte spielen</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="77"/>
        <source>Map is allowed for one player and cannot be started</source>
        <translation>Karte ist für einen Spieler erlaubt und kann nicht gestartet werden</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="79"/>
        <source>No human players allowed to play this map</source>
        <translation>Keine menschlichen Spieler dürfen diese Karte spielen</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="95"/>
        <source>Armored instance %1 is UNFLAGGABLE but must have NEUTRAL or player owner</source>
        <translation>Gepanzerte Instanz %1 ist UNFLAGGABLE, muss aber NEUTRAL oder Spielerbesitzer haben</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="101"/>
        <source>Object %1 is assigned to non-playable player %2</source>
        <translation>Objekt %1 ist dem nicht spielbaren Spieler %2 zugewiesen</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="108"/>
        <source>Town %1 has undefined owner %2</source>
        <translation>Stadt %1 hat undefinierten Besitzer %2</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="118"/>
        <source>Prison %1 must be a NEUTRAL</source>
        <translation>Gefängnis %1 muss NEUTRAL sein</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="124"/>
        <source>Hero %1 must have an owner</source>
        <translation>Held %1 muss einen Besitzer haben</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="129"/>
        <source>Hero %1 is prohibited by map settings</source>
        <translation>Held %1 ist durch Karteneinstellungen verboten</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="132"/>
        <source>Hero %1 has duplicate on map</source>
        <translation>Held %1 hat Duplikat auf Karte</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="135"/>
        <source>Hero %1 has an empty type and must be removed</source>
        <translation>Held %1 hat einen leeren Typ und muss entfernt werden</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="146"/>
        <source>Spell scroll %1 is prohibited by map settings</source>
        <translation>Zauberschriftrolle %1 ist durch Karteneinstellungen verboten</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="149"/>
        <source>Spell scroll %1 doesn&apos;t have instance assigned and must be removed</source>
        <translation>Zauberschriftrolle %1 hat keine Instanz zugewiesen und muss entfernt werden</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="155"/>
        <source>Artifact %1 is prohibited by map settings</source>
        <translation>Artefakt %1 ist durch Karteneinstellungen verboten</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="164"/>
        <source>Player %1 doesn&apos;t have any starting town</source>
        <translation>Spieler %1 hat keine Startstadt</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="168"/>
        <source>Map name is not specified</source>
        <translation>Kartenname ist nicht angegeben</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="170"/>
        <source>Map description is not specified</source>
        <translation>Kartenbeschreibung ist nicht angegeben</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="177"/>
        <source>Map contains object from mod &quot;%1&quot;, but doesn&apos;t require it</source>
        <translation>Karte enthält Objekt aus Mod &quot;%1&quot;, benötigt es aber nicht</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="183"/>
        <source>Exception occurs during validation: %1</source>
        <translation>Bei der Validierung ist eine Ausnahme aufgetreten: %1</translation>
    </message>
    <message>
        <location filename="../validator.cpp" line="187"/>
        <source>Unknown exception occurs during validation</source>
        <translation>Unbekannte Ausnahme trat während der Validierung auf</translation>
    </message>
</context>
<context>
    <name>VictoryConditions</name>
    <message>
        <location filename="../mapsettings/victoryconditions.ui" line="14"/>
        <source>Form</source>
        <translation>Formular</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.ui" line="40"/>
        <source>Victory message</source>
        <translation>Siegesnachricht</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.ui" line="59"/>
        <source>Only for human players</source>
        <translation>Nur für menschliche Spieler</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.ui" line="66"/>
        <source>Allow standard victory</source>
        <translation>Standardsieg zulassen</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.ui" line="79"/>
        <source>Parameters</source>
        <translation>Parameter</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="36"/>
        <source>No special victory</source>
        <translation>Kein besonderer Sieg</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="37"/>
        <source>Capture artifact</source>
        <translation>Artefakt sammeln</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="38"/>
        <source>Hire creatures</source>
        <translation>Kreaturen anheuern</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="39"/>
        <source>Accumulate resources</source>
        <translation>Ressourcen ansammeln</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="40"/>
        <source>Construct building</source>
        <translation>Gebäude errichten</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="41"/>
        <source>Capture town</source>
        <translation>Stadt einnehmen</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="42"/>
        <source>Defeat hero</source>
        <translation>Held besiegen</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="43"/>
        <source>Transport artifact</source>
        <translation>Artefakt transportieren</translation>
    </message>
    <message>
        <location filename="../mapsettings/victoryconditions.cpp" line="44"/>
        <source>Kill monster</source>
        <translation>Monster töten</translation>
    </message>
</context>
<context>
    <name>WindowNewMap</name>
    <message>
        <location filename="../windownewmap.ui" line="32"/>
        <source>Create new map</source>
        <translation>Neue Karte erstellen</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="47"/>
        <source>Map size</source>
        <translation>Größe der Karte</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="62"/>
        <source>Two level map</source>
        <translation>Karte mit zwei Ebenen</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="82"/>
        <source>Height</source>
        <translation>Höhe</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="114"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="152"/>
        <source>S (36x36)</source>
        <translation>S (36x36)</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="157"/>
        <source>M (72x72)</source>
        <translation>M (72x72)</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="162"/>
        <source>L (108x108)</source>
        <translation>L (108x108)</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="167"/>
        <source>XL (144x144)</source>
        <translation>XL (144x144)</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="193"/>
        <source>Random map</source>
        <translation>Zufallsgenerierte Karte</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="205"/>
        <source>Players</source>
        <translation>Spieler</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="724"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="349"/>
        <source>Human/Computer</source>
        <translation>Mensch/Computer</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="221"/>
        <location filename="../windownewmap.ui" line="289"/>
        <location filename="../windownewmap.ui" line="443"/>
        <location filename="../windownewmap.ui" line="584"/>
        <source>Random</source>
        <translation>Zufall</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="269"/>
        <source>Computer only</source>
        <translation>Nur Computer</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="380"/>
        <source>Human teams</source>
        <translation>Menschliche Teams</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="399"/>
        <source>Computer teams</source>
        <translation>Computer Teams</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="416"/>
        <source>Monster strength</source>
        <translation>Monster-Stärke</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="465"/>
        <source>Weak</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="484"/>
        <location filename="../windownewmap.ui" line="625"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="503"/>
        <source>Strong</source>
        <translation>Stark</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="557"/>
        <source>Water content</source>
        <translation>Wasseranteil</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="606"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="644"/>
        <source>Islands</source>
        <translation>Inseln</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="689"/>
        <source>Template</source>
        <translation>Vorlage</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="737"/>
        <source>Custom seed</source>
        <translation>Benutzerdefiniertes Seed</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="751"/>
        <source>Generate random map</source>
        <translation>Zufällige Karte generieren</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="785"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../windownewmap.ui" line="804"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../windownewmap.cpp" line="276"/>
        <source>No template</source>
        <translation>Kein Template</translation>
    </message>
    <message>
        <location filename="../windownewmap.cpp" line="276"/>
        <source>No template for parameters scecified. Random map cannot be generated.</source>
        <translation>Es wurde kein Template für Parameter erstellt. Zufällige Karte kann nicht generiert werden.</translation>
    </message>
    <message>
        <location filename="../windownewmap.cpp" line="296"/>
        <source>RMG failure</source>
        <translation>RMG-Fehler</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../mainwindow.cpp" line="106"/>
        <source>Filepath of the map to open.</source>
        <translation>Dateipfad der zu öffnenden Karte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Extract original H3 archives into a separate folder.</source>
        <translation>Extrahieren Sie die Original-H3-Archive in einen separaten Ordner.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>From an extracted archive, it Splits TwCrPort, CPRSMALL, FlagPort, ITPA, ITPt, Un32 and Un44 into individual PNG&apos;s.</source>
        <translation>Aus einem extrahierten Archiv zerlegt es TwCrPort, CPRSMALL, FlagPort, ITPA, ITPt, Un32 und Un44 in einzelne PNGs.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="111"/>
        <source>From an extracted archive, Converts single Images (found in Images folder) from .pcx to png.</source>
        <translation>Aus einem extrahierten Archiv werden einzelne Bilder (aus dem Ordner &quot;Images&quot;) von .pcx in png konvertiert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Delete original files, for the ones split / converted.</source>
        <translation>Löschen Sie die Originaldateien für die gesplitteten/konvertierten Dateien.</translation>
    </message>
</context>
</TS>
